pygeodesy.geodesicx.gxline

Package pygeodesy :: Package geodesicx :: Module gxline |
[frames] | no frames]

# Module gxline

A pure Python version of Karney's C++ class GeodesicLineExact.

Class GeodesicLineExact follows the naming, methods and return values from class `GeodesicLine` from Karney's Python geographiclib.

Copyright (C) Charles Karney (2008-2023) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.09.09

Classes
| _GeodesicLineExact (INTERNAL) Base class for GeodesicLineExact.